==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/AlignRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescriptionMetadata } from "./FormatRadialGaugeLabelEventArgsDescriptionMetadata";
import { AlignRadialGaugeLabelEventArgsDescription } from "./AlignRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
export let AlignRadialGaugeLabelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AlignRadialGaugeLabelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AlignRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
                AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AlignRadialGaugeLabelEventArgsDescriptionMetadata.c(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
            }
            if (a.j(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            AlignRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
            a.aa("AlignRadialGaugeLabelEventArgs", () => new AlignRadialGaugeLabelEventArgsDescription());
            a.z("AlignRadialGaugeLabelEventArgs", AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
    }
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AlignRadialGaugeLabelEventArgsDescriptionMetadata, 'AlignRadialGaugeLabelEventArgsDescriptionMetadata');
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return AlignRadialGaugeLabelEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/AlignRadialGaugeLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatRadialGaugeLabelEventArgsDescriptionMetadata } from "./FormatRadialGaugeLabelEventArgsDescriptionMetadata";
import { AlignRadialGaugeLabelEventArgsDescription } from "./AlignRadialGaugeLabelEventArgsDescription";
/**
 * @hidden
 */
export let AlignRadialGaugeLabelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AlignRadialGaugeLabelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AlignRadialGaugeLabelEventArgsDescriptionMetadata.a == null) {
                AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AlignRadialGaugeLabelEventArgsDescriptionMetadata.c(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
            }
            if (a.k(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            FormatRadialGaugeLabelEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            AlignRadialGaugeLabelEventArgsDescriptionMetadata.b(a);
            a.ac("AlignRadialGaugeLabelEventArgs", () => new AlignRadialGaugeLabelEventArgsDescription());
            a.ab("AlignRadialGaugeLabelEventArgs", AlignRadialGaugeLabelEventArgsDescriptionMetadata.a);
        }
    }
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(AlignRadialGaugeLabelEventArgsDescriptionMetadata, 'AlignRadialGaugeLabelEventArgsDescriptionMetadata');
    AlignRadialGaugeLabelEventArgsDescriptionMetadata.a = null;
    return AlignRadialGaugeLabelEventArgsDescriptionMetadata;
})();
